SystemOrganization addCategory: #'OCMS-Kernel'!

Object subclass: #Comment
	instanceVariableNames: 'id login user dateAndTime text'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Comment commentStamp: 'HAS 4/30/2013 20:35' prior: 0!
I represent comments made by users regarding the courseware.!

!Comment methodsFor: 'accessing' stamp: 'has 6/23/2013 08:00'!
createId
	id:= self hash.! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:09'!
dateAndTime

	^ dateAndTime! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:09'!
dateAndTime: aDateAndTime

	dateAndTime := aDateAndTime! !

!Comment methodsFor: 'comparing' stamp: 'has 6/24/2013 06:45'!
hash
	(self user isNil)
		ifTrue:[self user: ''].
	(self dateAndTime isNil)
		ifTrue:[self dateAndTime: ''].
	(self text isNil)
		ifTrue: [self text: ''].
	^[self user login, '|',  self dateAndTime, '|', self text] value hash.! !

!Comment methodsFor: 'accessing' stamp: 'has 6/23/2013 08:00'!
id
	^id! !

!Comment methodsFor: 'testing' stamp: 'has 6/1/2013 23:17'!
isComment
	^ true.! !

!Comment methodsFor: 'accessing' stamp: 'has 6/24/2013 15:26'!
login
	^user login.! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:08'!
text

	^ text! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:08'!
text: aText

	text := aText! !

!Comment methodsFor: 'accessing' stamp: 'has 6/23/2013 00:22'!
user

	^user! !

!Comment methodsFor: 'accessing' stamp: 'HAS 4/30/2013 20:07'!
user: anUser

	user := anUser! !

Object subclass: #Courseware
	instanceVariableNames: 'id title description summary coursewareType owner reference tag course author creationDateTime modificationDateTime cataloguingData license size comment score usersWithWritePermission isEnabled downloadCounter file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Courseware commentStamp: 'HAS 4/28/2013 17:10' prior: 0!
Contains information about courseware

Instance variables:
	id <Long>										Unique identification
	title <String>										Title
	description <String>								Description
	summary <String>								A summary of the courseware's contents (optional)
	coursewareType <Symbol>						Type of courseware getting from CoursewareTypeSet class variable
	owner <User>									User that upload the courseware	
	reference <String>								Information about authors, journal, url, related courseware,...
	tag <List of: Tag>								A sorted list of tags related
	classification <List of: Discipline>					Disciplines/Areas related to the courseware
	author <List of: String>							Author(s) of the courseare in a ordered list
	creationDateTime <DateAndTime>					Date and time in which the courseware was uploaded
	modificationDateTime <DateAndTime>				Date and time of the last modification of the courseware
	cataloguingData <String>							Information about cataloguing data.
	license <LicenseType>							Type of license described in LicenseTypeSet class variable
	size <Integer>									Size of the courseware in K bytes
	comment <List of: Comment>						A list of comments of the courseware
	score <Map of: User and Float>					A map representing the score atributed by each user
	permission <Map of: User and PermissionType>	A map associating user and type of permission that they have
	enabled <Boolean>								A flag that indicates if the courseware is enable or not
	downloadCounter <Integer>						Number of downloads of the courseware
	file <File>										File name and extension of courseware!

!Courseware methodsFor: 'accessing' stamp: 'has 6/1/2013 16:57'!
author
	"I return an OrderedCollection of strings containing the name of the authors"

	^ author! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/1/2013 17:01'!
author: anOrderedCollectionString
	"I receive an OrderedCollection of String with the author's name"
	
	author := anOrderedCollectionString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:58'!
cataloguingData
	^ cataloguingData! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:58'!
cataloguingData: aString
	cataloguingData := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:01'!
comment
	^ comment! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/30/2013 23:14'!
comment: anOrderedCollectionComment
	comment := anOrderedCollectionComment! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 00:20'!
course
	^ course! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 00:20'!
course: aSortedCollectionCourse
	course := aSortedCollectionCourse! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:22'!
coursewareType
	^ coursewareType! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/24/2013 09:56'!
coursewareType: aSymbol
	(CoursewareType coursewareTypeList includes: aSymbol)
		ifTrue:[coursewareType := aSymbol]
		ifFalse:[self error: 'This CoursewareType does not exist']! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:57'!
creationDateTime
	^ creationDateTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:57'!
creationDateTime: aDateAndTime
	creationDateTime := aDateAndTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:18'!
description
	^ description! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:19'!
description: aString
	description := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:08'!
downloadCounter
	^ downloadCounter! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:08'!
downloadCounter: anInteger
	downloadCounter := anInteger! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:09'!
file
	^ file! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:09'!
file: aFile
	file := aFile! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 12:18'!
id
	^ id! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/2/2013 17:42'!
id: anInteger
	(anInteger isInteger)
		ifTrue:[id := anInteger]
		ifFalse:[self error: 'The value must be an integer']! !

!Courseware methodsFor: 'initialize' stamp: 'has 6/24/2013 09:53'!
initialize
	self downloadCounter: 0.
	self isEnabled: true.
	self usersWithWritePermission: OrderedCollection new.
	self comment: OrderedCollection new.
	self tag: OrderedCollection new.
	self course: OrderedCollection new.
	self author: OrderedCollection new.
	self score: Dictionary new.! !

!Courseware methodsFor: 'testing' stamp: 'HAS 4/28/2013 19:54'!
isCourseware
	^true! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/12/2013 08:07'!
isEnabled
	^ isEnabled! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/12/2013 08:07'!
isEnabled: aBoolean
	isEnabled := aBoolean! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:59'!
license
	^ license! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:59'!
license: aLicense
	license := aLicense! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/29/2013 19:50'!
modificationDateTime
	^ modificationDateTime! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/29/2013 19:50'!
modificationDateTime: aDateAndTime
	modificationDateTime := aDateAndTime! !

!Courseware methodsFor: 'instance creation' stamp: 'HAS 4/30/2013 10:48'!
new
	| newCourseware |
	
	newCourseware := super.
	newCourseware initialize.
	^newCourseware
! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 01:09'!
owner
	^ owner! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:44'!
owner: aUser
	owner := aUser! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:58'!
reference
	^ reference! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 07:59'!
reference: aString
	reference := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:01'!
score
	^ score! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:05'!
score: aMapOfUserAndFloat
	score := aMapOfUserAndFloat! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:00'!
size
	^ size! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:00'!
size: aFloat
	size := aFloat! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:20'!
summary
	^ summary! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 15:19'!
summary: aString
	summary := aString! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 16:40'!
tag
	^tag! !

!Courseware methodsFor: 'accessing' stamp: 'has 6/2/2013 10:52'!
tag: anOrderedCollectionTag
	
	(anOrderedCollectionTag isMemberOf: OrderedCollection)
		ifTrue: [tag := anOrderedCollectionTag]
		ifFalse: [self error: 'This method must receives an OrderedCollection of Tag']
! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/27/2013 14:00'!
title
	^ title! !

!Courseware methodsFor: 'accessing' stamp: 'HAS 4/28/2013 17:38'!
title: anString
	title := anString! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 08:01'!
usersWithWritePermission
	^ usersWithWritePermission! !

!Courseware methodsFor: 'accessing' stamp: 'has 5/29/2013 08:02'!
usersWithWritePermission: anUserOrderedCollection
	usersWithWritePermission := anUserOrderedCollection! !

Object subclass: #CoursewareManager
	instanceVariableNames: 'courseware coursewareList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!CoursewareManager commentStamp: 'HAS 4/29/2013 10:31' prior: 0!
This class manages coursewares, which include methods to search, edit and classify a courseware.

	courseware <Courseware>	Represent a courseware!

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:14'!
blockCourseware: aCourseware user: anUser
	"I block the couseware if the user has the permissions to do this"
	
	| notification |
	anUser isUser.
	aCourseware isCourseware.
	notification := OCMSNotificationManager new.
	
	(anUser isAdmin or: (self isOwner: anUser ofCourseware: aCourseware) or: (self isProfessor: anUser atCourseware: aCourseware))
		ifTrue:[(aCourseware isEnabled)
				ifTrue:[aCourseware isEnabled: false]
				ifFalse:[self error: 'This courseware was already blocked.'].
				]
		ifFalse:[self error: 'You do not have permission to block this courseware.'].
	self updateCourseware: aCourseware.
	notification blockCoursewareNotification: aCourseware.
	^ aCourseware! !

!CoursewareManager methodsFor: 'calculating' stamp: 'has 6/2/2013 10:19'!
calculateRatingScore: aCourseware
	"I calculate the rating score from the scores gave by the users"
	| rating scoreDictionary |
	
	aCourseware isCourseware.
	rating := 0.
	scoreDictionary := aCourseware score.
	scoreDictionary valuesDo: [:each | rating := rating + each].
	rating := rating / scoreDictionary size.
	^ rating.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 10:32'!
courseware
	^ courseware! !

!CoursewareManager methodsFor: 'accessing' stamp: 'HAS 4/29/2013 10:33'!
courseware: aCourseware
	courseware := aCourseware! !

!CoursewareManager methodsFor: 'testing' stamp: 'has 6/24/2013 07:14'!
hasWritePermission: anUser withCourseware: aCourseware
	"i check if user has write permission to the courseware"
	
	anUser isUser.
	aCourseware isCourseware.
	
	(aCourseware usersWithWritePermission includes: anUser)
		ifTrue:[^ true].
	^ false.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 09:10'!
includeAuthor: anAuthor ofCourseware:aCourseware 
	"i include a an author in courseware"
	
	| authorCollection |
	
	aCourseware isCourseware.
		
	authorCollection := aCourseware comment.
	authorCollection add: anAuthor.
	aCourseware author: authorCollection.
	self updateCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:16'!
includeComment: aCourseware comment: aComment
	"i include a comment of an user in courseware"
	
	| commentCollection notification |
	
	aCourseware isCourseware.
	aComment isComment.
	notification := OCMSNotificationManager new.
		
	commentCollection := aCourseware comment.
	commentCollection add: aComment.
	aCourseware comment: commentCollection.
	self updateCourseware: aCourseware.
	Comments add: aComment.
	notification newCommentNotification: aComment ofCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'creating' stamp: 'has 6/24/2013 07:43'!
includeCourseware: aCourseware
	"I include a new courseware"
	| notification |
	aCourseware isCourseware.
	notification := OCMSNotificationManager new.
	Coursewares add: aCourseware.
	notification newCoursewareNotification: aCourseware.! !

!CoursewareManager methodsFor: 'creating' stamp: 'has 6/24/2013 07:45'!
includeCourseware: aTitle withDescription: aDescription withSummary: aSummary withCoursewareType: aCoursewareType withReference: aReference withOwner: anOwner withTag: aTagList withCourse: aCourseList withAuthor: anAuthorList withCataloguingData: aCataloguingData withLicense: aLicenseType withSize: aSize withFile: aFile
	"I include a new courseware"
	| coursewareTemp |
	coursewareTemp := Courseware new.
	coursewareTemp title: aTitle.
	coursewareTemp description: aDescription.
	coursewareTemp summary: aSummary.
	coursewareTemp coursewareType: aCoursewareType.
	coursewareTemp owner: anOwner.
	coursewareTemp reference: aReference.
	coursewareTemp tag: aTagList.
	coursewareTemp course: aCourseList.
	coursewareTemp author: anAuthorList.
	coursewareTemp creationDateTime: DateAndTime now.
	coursewareTemp modificationDateTime: nil.
	coursewareTemp cataloguingData: aCataloguingData.
	coursewareTemp license: aLicenseType.
	coursewareTemp size: aSize.
	coursewareTemp isEnabled: true.
	coursewareTemp downloadCounter: 0.
	coursewareTemp file: aFile.
	self includeCourseware: coursewareTemp.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:16'!
includeOrUpdateCoursewareScore: aCourseware ofUser: anUser withScore: aScore
	"include a score for the courseware gave by an User"

	| scoreDictionary login notification |

	aCourseware isCourseware.
	anUser isUser.
	aScore isNumber.
	notification := OCMSNotificationManager new.
	login := anUser login.
	scoreDictionary := aCourseware score.
	scoreDictionary at: login put: aScore.
	aCourseware score: scoreDictionary.

	self updateCourseware: aCourseware.
	notification scoreNotification: anUser ofCourseware: aCourseware.
	^aCourseware! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:17'!
includeUserWritePermission: aCourseware user: anUser
	"i include permissions to user write coursewares"
	
	| userSession notification |
	
	aCourseware isCourseware.
	anUser isUser.
	notification := OCMSNotificationManager new.
	"userSession must be an user in a System class"
	"userSession := System session."
	userSession := aCourseware owner.
	(self isOwner: anUser ofCourseware: aCourseware)
		ifTrue:[self error: 'The owner already has write permissions.'].
	(userSession isAdmin or: (self isOwner: userSession ofCourseware: aCourseware) or: (self isProfessor: userSession atCourseware: aCourseware))
		ifTrue:[
				((self hasWritePermission: anUser withCourseware: aCourseware) not)
					ifTrue:[aCourseware usersWithWritePermission add: anUser.
						^aCourseware]
					ifFalse:[self error: 'This user already has permission to the courseware']
				]
		ifFalse:[self error: 'You do not have permission to do this'].
		
	self updateCourseware: aCourseware.
	notification includeWritePermissionNotification: anUser ofCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:17'!
incrementDownloadCounter: aCourseware

	"increase the number of downloads of a courseware"
	
	aCourseware isCourseware.
	
	aCourseware downloadCounter: aCourseware downloadCounter + 1.
	self updateCourseware: aCourseware.
	^ aCourseware.! !

!CoursewareManager methodsFor: 'testing' stamp: 'has 6/24/2013 07:17'!
isOwner: anUser ofCourseware: aCourseware
	"i check if user is the owner of the courseware"
	
	aCourseware isCourseware.
	anUser isUser.
	
	(aCourseware owner = anUser)
		ifTrue:[^ true].
	^ false.! !

!CoursewareManager methodsFor: 'testing' stamp: 'has 6/24/2013 07:19'!
isProfessor: anUser atCourseware: aCourseware
	"i check if the user is professor at least one course of the courseware"
	
	[| courseList |
	anUser isUser.
	aCourseware isCourseware.

	courseList := aCourseware course.
	1 to: courseList size do: [:each | ((anUser roleAtCourse: (courseList at: each)) = UserType professor)
										ifTrue:[^ true]].
	^ false.]
	on: Exception
	do: [:sig | sig return: nil]! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:20'!
removeUserWritePermission: aCourseware user: anUser
	"i remove permissions to user write coursewares"
	
	| userSession notification |
	"userSession must be an user in a System class"
	"userSession := System session."
	notification := OCMSNotificationManager new.
	userSession := aCourseware owner.
	(userSession isAdmin or: (self isOwner: userSession ofCourseware: aCourseware) or: (self isProfessor: userSession atCourseware: aCourseware))
		ifTrue:[
				(self hasWritePermission: anUser withCourseware: aCourseware)
					ifTrue:[aCourseware usersWithWritePermission add: anUser.
							^aCourseware]
					ifFalse:[self error: 'This user cannot has permission to the courseware']
				]
		ifFalse:[self error: 'You do not have permission to do this'].
		
	self updateCourseware: aCourseware.
	notification removeWritePermissionNotification: anUser ofCourseware: aCourseware.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 6/2/2013 10:02'!
searchAllCoursewares
	"i return an ordered collection with all coursewares"
	| coursewareList |
	
	coursewareList := OrderedCollection new.
	coursewareList := Coursewares getAll. "asOrderedCollection"
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:52'!
searchCoursewareByAuthor: aString
	"i return an ordered collection of the coursewares from a same author"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByAuthor: aString."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:56'!
searchCoursewareByCourse: aCourse
	"i return an ordered collection of the coursewares from a same rating"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByCourse: aCourse."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 6/2/2013 09:39'!
searchCoursewareById: anId
	"i return a courseware with the typed id"
	
	anId isInteger.
	
	self courseware: (Coursewares searchById: anId).
	^ self courseware.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:51'!
searchCoursewareByOwner: anUser
	"i return an ordered collection of the coursewares from a same owner"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByOwner: anUser."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:54'!
searchCoursewareByRating: aValue
	"i return an ordered collection of the coursewares with the same rating"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByRating: aValue."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 16:53'!
searchCoursewareByTag: aTag
	"i return an ordered collection of the coursewares with the same tag"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByTag: aTag."
	^ coursewareList! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 6/3/2013 10:44'!
searchCoursewareByTitle: aTitle
	"i return an ordered collection of coursewares with the typed title"
	| coursewareList |
	
	coursewareList := OrderedCollection new.
	coursewareList := Coursewares searchByTitle: aTitle. "asOrderedCollection."
	^ coursewareList.! !

!CoursewareManager methodsFor: 'accessing' stamp: 'has 5/13/2013 19:53'!
searchCoursewareByUser: anUser withPermission: aPermissionType
	"i return an ordered collection of the coursewares in which an user has a type of permission"
	| coursewareList coursewareDao|
	
	coursewareList := OrderedCollection new.
	"coursewareDao := CoursewareDAO new.
	coursewareList := cousewareDao searchCoursewareByUser: anUser withPermission: aPermissionType."
	^ coursewareList! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:30'!
unblockCourseware: aCourseware user: anUser
	"I unblock the couseware if the user has the permissions to do this"

	| notification |
	anUser isUser.
	aCourseware isCourseware.
	notification := OCMSNotificationManager new.
	
	(anUser isAdmin or: (self isOwner: anUser ofCourseware: aCourseware) or: (self isProfessor: anUser atCourseware: aCourseware))
		ifTrue:[(aCourseware isEnabled not)
				ifTrue:[aCourseware isEnabled: true]
				ifFalse:[self error: 'This courseware was already enabled.'].
				]
		ifFalse:[self error: 'You do not have permission to unblock this courseware.'].
	self updateCourseware: aCourseware.
	notification unblockCoursewareNotification: aCourseware.
	^ aCourseware! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:07'!
updateCourseware: aCourseware
	"i update the courseware information"
	
	aCourseware isCourseware.
	Coursewares update: aCourseware.! !

!CoursewareManager methodsFor: 'updating' stamp: 'has 6/24/2013 07:09'!
updateCourseware: aCourseware withTitle: aTitle withDescription: aDescription withSummary: aSummary withCoursewareType: aCoursewareType withReference: aReference withTag: aTagList withCourse: aCourseList withAuthor: aAuthorList withCataloguingData: aCataloguingData withLicense: aLicenseType withSize: aSize withScore: aUserFloatDictionary withPermission: aUserPermissionTypeDictionary withFile: aFile
	"i update the courseware information"
	
	| coursewareTemp |
	coursewareTemp := aCourseware.
	coursewareTemp title: aTitle.
	coursewareTemp description: aDescription.
	coursewareTemp summary: aSummary.
	coursewareTemp coursewareType: aCoursewareType.
	coursewareTemp reference: aReference.
	coursewareTemp tag: aTagList.
	coursewareTemp course: aCourseList.
	coursewareTemp author: aAuthorList.
	coursewareTemp modificationDateTime: DateAndTime now.
	coursewareTemp cataloguingData: aCataloguingData.
	coursewareTemp license: aLicenseType.
	coursewareTemp size: aSize.
	coursewareTemp score: aUserFloatDictionary.
	coursewareTemp permission: aUserPermissionTypeDictionary.
	coursewareTemp file: aFile.
	self updateCourseware: coursewareTemp.
	^coursewareTemp.
	! !

Object subclass: #CoursewareType
	instanceVariableNames: ''
	classVariableNames: 'CoursewareTypeList'
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!CoursewareType commentStamp: '<historical>' prior: 0!
UserType class is used to enumerate roles of users, so it can be used to set roles of users within Disciplines.

There are the following roles that can be accessed by class methods:
	student
	professor

UserTypeList is a class variable that contains a set with all roles availables.
!

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:49'!
audio
	^ #Audio! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:49'!
code
	^ #Code! !

!CoursewareType class methodsFor: 'class variables' stamp: 'has 6/24/2013 09:55'!
coursewareTypeList
	CoursewareTypeList ifNil: [CoursewareTypeList := Set new add: CoursewareType audio; 
																add: CoursewareType code;
																add: CoursewareType exercise; 
																add: CoursewareType program; 
																add: CoursewareType slide; 
																add: CoursewareType text; 
																add: CoursewareType video; 
																yourself].
	^ CoursewareTypeList! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:49'!
exercise
	^ #Exercise! !

!CoursewareType class methodsFor: 'instance creation' stamp: 'has 6/24/2013 09:43'!
new
	self error: 'This class should not be instanciated'! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
program
	^ #Program! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
slide
	^ #Slide! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
text
	^ #Text! !

!CoursewareType class methodsFor: 'accessing' stamp: 'has 6/24/2013 09:50'!
video
	^ #Video! !

Object subclass: #OCMSNotification
	instanceVariableNames: 'id title body sender receiverIsRead isSystemNotification dateAndTime'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!OCMSNotification methodsFor: 'comparing' stamp: 'oda 5/12/2013 22:58'!
= aOCMSNotification
	^self hash = aOCMSNotification hash.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/13/2013 03:52'!
addReceiver: anUser
	"Adds a receiver with the relation that the message has not been read."
	receiverIsRead at: anUser put: false.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/23/2013 11:51'!
addReceiverList: anUserList
	"I add a list of receivers with the relation that the message has not been read."
	anUserList do: [:each | receiverIsRead at: each put: false.].! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 23:32'!
body
	"Answer the value of body"

	^ body! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 23:32'!
body: anObject
	"Set the value of body"

	body := anObject! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/23/2013 07:59'!
createId
	id:= self hash.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
dateAndTime
	"Answer the value of dateAndTime"

	^ dateAndTime! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
dateAndTime: anObject
	"Set the value of dateAndTime"

	dateAndTime := anObject! !

!OCMSNotification methodsFor: 'comparing' stamp: 'has 6/24/2013 15:46'!
hash
	| receiverLogin senderLogin|
	receiverLogin := ''.
	self receiver do: [:each | receiverLogin := receiverLogin, '|', each ].
	(sender isNil)
		ifTrue: [senderLogin := '']
		ifFalse: [senderLogin := sender login].
	
	^ [title, '|',  body, receiverLogin, '|', senderLogin, '|', dateAndTime] value hash.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/23/2013 07:57'!
id
	^id.! !

!OCMSNotification methodsFor: 'initialize-release' stamp: 'oda 5/13/2013 04:30'!
initialize
	sender := nil.
	receiverIsRead := Dictionary new.
	isSystemNotification := false.
	dateAndTime := DateAndTime now.! !

!OCMSNotification methodsFor: 'testing' stamp: 'has 6/23/2013 15:14'!
isOCMSNotification
	^true.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/24/2013 17:25'!
isReadByUser: anUser
	^ receiverIsRead at: anUser.
	! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:24'!
isSystemNotification
	"Answer the value of isSystemNotification"

	^ isSystemNotification! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:24'!
isSystemNotification: anObject
	"Set the value of isSystemNotification"

	isSystemNotification := anObject! !

!OCMSNotification methodsFor: 'accessing' stamp: 'has 6/24/2013 17:37'!
readWithUser: anUser
	(self receiver includes: anUser)
		ifTrue: [receiverIsRead at: anUser put: true].! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/13/2013 03:53'!
receiver
	"Answer the value of receiver set"

	^ receiverIsRead keys.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/13/2013 04:03'!
receiverIsRead
	"Answer the value of receiverIsRead"

	^ receiverIsRead.! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
sender
	"Answer the value of sender"

	^ sender! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
sender: anObject
	"Set the value of sender"

	sender := anObject! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
title
	"Answer the value of title"

	^ title! !

!OCMSNotification methodsFor: 'accessing' stamp: 'oda 5/12/2013 22:13'!
title: anObject
	"Set the value of title"

	title := anObject! !

Object subclass: #OCMSNotificationManager
	instanceVariableNames: 'notification'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:04'!
blockCoursewareNotification: aCourseware
	"I create a notification when a courseware is blocked."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Courseware blocked'.
	newNotification body: 'The courseware ',aCourseware title,' was blocked.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers addAll: userManager getAllAdmins.
	receivers addAll: aCourseware usersWithWritePermission.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (userManager getProfessorsAtCourse:each)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 18:59'!
blockUserNotification: anUser
	"I create a notification when a user is blocked"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'User blocked'.
	newNotification body: 'The user with login ',anUser login,' was blocked.'.
	newNotification isSystemNotification: true.
	receivers add: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'has 6/24/2013 17:40'!
hasUnreadNotificationOfUser: anUser
	"Returns true if exists at least one unread notification received by anUser"
	| aSet notificationTemp |
	notificationTemp := self receivedNotificationOfUser:anUser.
	aSet := (notificationTemp select: [:each | ((each isReadByUser: anUser) = false)]).
	^aSet isEmpty not.
	! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 15:19'!
includeNotification: newNotification
	"I include a new notification in database."
	newNotification isOCMSNotification.
	newNotification createId.
	OCMSNotifications add: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:06'!
includeWritePermissionNotification: anUser ofCourseware: aCourseware
	"I create a notification when an user has write permissions to a courseware."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Write permissions to courseware'.
	newNotification body: anUser login,' now has write permission to courseware ',aCourseware title,'.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers add: anUser.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (userManager getProfessorsAtCourse:each)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'initialize-release' stamp: 'oda 5/12/2013 23:04'!
initialize
	notification := Set new.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 16:51'!
newCommentNotification: aComment ofCourseware: aCourseware
	"I create a notification when a comment is created"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New comment'.
	newNotification body: 'User ',(aComment user) login,' made a comment about ', aCourseware.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 18:09'!
newCoursewareNotification: aCourseware
	"I create a notification when a new courseware is created."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New courseware'.
	newNotification body: 'A new courseware with the title ',aCourseware title,' was created.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (userManager getProfessorsAtCourse:each)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 15:22'!
newUserNotification: anUser
	"I create a notification when a new user is created"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New user'.
	newNotification body: 'A new user with login ',anUser login,' was created.'.
	newNotification isSystemNotification: true.
	receivers add: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'oda 5/13/2013 03:19'!
notification
	"Answer the value of notification"

	^ notification! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'has 6/24/2013 17:42'!
receivedNotificationOfUser: anUser
	"I return all notifications received by anUser"
	| notificationTemp userNotification |
	anUser isUser.
	notificationTemp := OCMSNotifications getAll.
	userNotification := (notificationTemp select: [:each | ((each receiver includes: anUser) = true)]).
	^userNotification.
	! !

!OCMSNotificationManager methodsFor: 'updating' stamp: 'has 6/24/2013 17:44'!
removeNotification: aNotification
	"i remove the notification"
	aNotification isOCMSNotification.
	OCMSNotifications remove: aNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:06'!
removeWritePermissionNotification: anUser ofCourseware: aCourseware
	"I create a notification when an user lost his write permissions to a courseware."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Lost write permissions to courseware'.
	newNotification body: anUser login,' lost his write permissions to courseware ',aCourseware title,'.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers add: anUser.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (userManager getProfessorsAtCourse:each)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:13'!
scoreNotification: anUser ofCourseware: aCourseware
	"I create a notification when a score is assigned to a courseware"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'New score'.
	newNotification body: 'User ',anUser login,' assigned a score for', aCourseware.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:26'!
sendMessageToAdminFrom: anUser withTitle: aTitle withContent: aMessage
	"I create a message to be sent to admin group"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:33'!
sendMessageToOwnerFrom: anUser ofCourseware: aCourseware withTitle: aTitle withContent: aMessage
	"I create a message to be sent to the owner of a courseware"
	
	| newNotification receivers |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers add: aCourseware owner.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:36'!
sendMessageToProfessorsFrom: anUser ofCourse: aCourse withTitle: aTitle withContent: aMessage
	"I create a message to be sent to professors of a course"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers addAll: (userManager getProfessorsAtCourse: aCourse).
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:42'!
sendMessageToWritePermissionsUsersFrom: anUser ofCourseware: aCourseware withTitle: aTitle withContent: aMessage
	"I create a message to be sent to users with write permissions of a courseware"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: aTitle.
	newNotification body: aMessage.
	newNotification isSystemNotification: false.
	newNotification sender: anUser.
	receivers add: aCourseware owner.
	receivers addAll: aCourseware usersWithWritePermission.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (userManager getProfessorsAtCourse:each)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'accessing' stamp: 'has 6/24/2013 17:48'!
sentNotificationOfUser: anUser
	"I return all notifications that were sent by anUser"
	| notificationTemp userNotification |
	anUser isUser.
	notificationTemp := OCMSNotifications getAll.
	userNotification := notificationTemp select: [:each | (each sender = anUser)].
	^userNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 19:16'!
unblockCoursewareNotification: aCourseware
	"I create a notification when a courseware is unblocked."
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'Courseware unblocked'.
	newNotification body: 'The courseware ',aCourseware title,' was unblocked.'.
	newNotification isSystemNotification: true.
	receivers add: aCourseware owner.
	receivers addAll: userManager getAllAdmins.
	receivers addAll: aCourseware usersWithWritePermission.
	((aCourseware course) size > 0)
		ifTrue:[(aCourseware course) do: [:each | receivers addAll: (userManager getProfessorsAtCourse:each)]].
	"tirar duplicados"
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

!OCMSNotificationManager methodsFor: 'creating' stamp: 'has 6/23/2013 18:59'!
unblockUserNotification: anUser
	"I create a notification when a user is unblocked"
	
	| newNotification receivers userManager |
	
	newNotification:= OCMSNotification new.
	receivers:= OrderedCollection new.
	userManager:= UserManager new.
	newNotification title: 'User unblocked'.
	newNotification body: 'The user with login ',anUser login,' was unblocked.'.
	newNotification isSystemNotification: true.
	receivers add: anUser.
	receivers addAll: userManager getAllAdmins.
	newNotification addReceiverList: receivers.
	self includeNotification: newNotification.! !

Object subclass: #Tag
	instanceVariableNames: 'name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!Tag commentStamp: 'HAS 4/28/2013 16:34' prior: 0!
Store the tags used to classify courseware.

	name <String>							Name of the tag.
	relatedTag <OrderedCollection of: Tag>		Contains the related tags.!

!Tag methodsFor: 'testing' stamp: 'HAS 4/28/2013 19:52'!
isTag
	^ true! !

!Tag methodsFor: 'accessing' stamp: 'HAS 4/28/2013 15:54'!
name
	^name! !

!Tag methodsFor: 'accessing' stamp: 'has 6/24/2013 13:32'!
name: aString
	"i put a name in a tag"
	name := aString
	! !

Object subclass: #TagManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!TagManager commentStamp: '<historical>' prior: 0!
Store the tags used to classify courseware.

	name <String>							Name of the tag.
	relatedTag <OrderedCollection of: Tag>		Contains the related tags.!

!TagManager methodsFor: 'creating' stamp: 'has 6/24/2013 13:29'!
includeTag: aTagName
	"i include a Tag"
	| tag |
	tag := Tag new.
	tag name: aTagName.
	
	Tags add: tag.! !

!TagManager methodsFor: 'updating' stamp: 'has 6/24/2013 13:29'!
removeTag: aTag
	"i remove a Tag"
	Tags removeTag: aTag.! !

!TagManager methodsFor: 'accessing' stamp: 'has 6/24/2013 13:29'!
searchTag: aTagName
	"i return a collection of tags that contains the typed word"
	| tagList |
	
	tagList := OrderedCollection new.
	tagList := Tags searchTag: aTagName. "as OrderedCollection."
	^ tagList.! !

!TagManager methodsFor: 'updating' stamp: 'has 6/24/2013 13:29'!
updateTag: aTag
	"i update a Tag"
	
	Tags update: aTag.! !

Object subclass: #User
	instanceVariableNames: 'name email login password isAdmin isEnabled courseRole'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!User commentStamp: 'oda 5/1/2013 20:21' prior: 0!
Contains information about user.

Instance Variables
	disciplineRole <Dictionary<Discipline, UserType>>		stores the role of the user within a discipline
	email <String>
	isEnabled <Boolean>
	isAdmin <Boolean>
	login <String>
	name <String>
	password <String>
!

!User methodsFor: 'comparing' stamp: 'oda 5/12/2013 21:55'!
= aUser
	^self login = aUser login! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 23:50'!
course
	"Answer the courses that the user has a role in"
	
	^ courseRole keys! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
email
	^ email! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
email: aString
	email := aString! !

!User methodsFor: 'comparing' stamp: 'oda 5/1/2013 22:59'!
hash
	^ login hash! !

!User methodsFor: 'creating' stamp: 'has 6/24/2013 10:04'!
includeOrUpdateCourse: aCourse withRole: aRole
	"Includes/updates an user role within a course.
	Use UserType methods the get a role."
	
	((aCourse isMemberOf: Course) and: [UserType userTypeList includes: aRole])
		ifTrue: [courseRole at: aCourse put: aRole]
		ifFalse: [self error: 'The course must be instance of Course class and the role must come from the UserType methods.']
	! !

!User methodsFor: 'initialize-release' stamp: 'oda 5/3/2013 21:35'!
initialize
	isEnabled := false.
	isAdmin := false.
	courseRole := Dictionary new.
	
	! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
isAdmin
	^ isAdmin! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 21:03'!
isAdmin: aBoolean
	isAdmin := aBoolean! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:41'!
isEnabled
	^ isEnabled! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:58'!
isEnabled: aBoolean
	isEnabled := aBoolean! !

!User methodsFor: 'testing' stamp: 'has 6/1/2013 18:14'!
isUser
	^ true! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:58'!
login
	^ login! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:58'!
login: aString
	login := aString! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:58'!
name
	^ name! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:59'!
name: aString
	name := aString! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:42'!
password
	^ password! !

!User methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:59'!
password: aString
	password := aString! !

!User methodsFor: 'accessing' stamp: 'has 6/23/2013 16:06'!
roleAtCourse: aCourse
	"Answer the role of user within a course"

	(aCourse isMemberOf: Course)
		ifTrue: [^courseRole at: aCourse]
		ifFalse: [self error: 'The course must be instance of Course class.'].
	! !

Object subclass: #UserManager
	instanceVariableNames: 'user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!UserManager commentStamp: 'oda 5/3/2013 22:00' prior: 0!
Manages users, can include new users, update existing ones, block/unblock users and is responsible for authentication.

Instance Variables
	user:<Set<User>>!

!UserManager methodsFor: 'testing' stamp: 'oda 5/3/2013 21:47'!
authenticateUserWithLogin: aLogin withPassword: aPassword
	"Asserts if user with aLogin exists and the password is correct."
	| anUser |
	anUser := self userWithLogin: aLogin.
	(anUser password = aPassword)
		ifTrue: [^true]
		ifFalse: [^false]! !

!UserManager methodsFor: 'updating' stamp: 'has 6/23/2013 19:01'!
blockUser: anUser
	"Blocks user."
	
	"userSession"
	"anUser isUser.
	notification := OCMSNotificationManager new.
	(userSession isAdmin)
		ifTrue:[	oldUser := Users searchByLogin: anUser login.
				(oldUser isEnabled)
					ifTrue:[	oldUser isEnabled: false.
							Users update: oldUser.
							notification blockUserNotification: anUser.]
					ifFalse:[self error: 'The user is already blocked.']].
		ifFalse:[self error: 'You do not have permissions to block an user']."
	| notification |
	notification := OCMSNotificationManager new.
	(anUser isMemberOf: User)
	ifFalse: [self error: 'The parameter must be member of the class User.']
	ifTrue: [
		(user includes: anUser)
			ifTrue: [
				| oldUser |
				oldUser := user array at:(user scanFor: anUser).
				oldUser isEnabled: false.
				notification blockUserNotification: anUser.
				^oldUser.
			]
			ifFalse: [self error: 'The login of this user does not exists.']
	]! !

!UserManager methodsFor: 'updating' stamp: 'has 6/2/2013 22:51'!
blockUserWithLogin: aLogin
	"Blocks user"
	| anUser |
	anUser := self userWithLogin: aLogin.
	self blockUser: anUser.! !

!UserManager methodsFor: 'testing' stamp: 'has 6/23/2013 11:03'!
emailExists: anEmail
	"I check if email already exists"
	| userTemp |
	userTemp:=Users searchByEmail: anEmail.
	(userTemp isNil)
		ifTrue:[^false]
		ifFalse:[^true].
	! !

!UserManager methodsFor: 'accessing' stamp: 'has 6/23/2013 12:31'!
getAllAdmins
	| admins users |
	users:= Users getAll.
	admins:= OrderedCollection new.
	users do:[:each | (each isAdmin)
						ifTrue:[admins add: each].].
	^admins.
	! !

!UserManager methodsFor: 'accessing' stamp: 'has 6/23/2013 16:13'!
getProfessorsAtCourse: aCourse
	| users professors |
	users:= Users getAll.
	professors:= OrderedCollection new.
	users do:[:each | (each roleAtCourse: aCourse = UserType professor)
						ifTrue:[professors add: each].].
	^professors.! !

!UserManager methodsFor: 'creating' stamp: 'has 6/23/2013 16:34'!
includeUser: anUser
	"I include a new user in database."
	| notification |
	anUser isUser.
	notification:= OCMSNotificationManager new.
	
	(anUser loginExists: anUser login)
		ifTrue: [self error: 'This login is already used'].
	(anUser emailExists: anUser email)
		ifTrue: [self error: 'This email is already used'].
	Users add: anUser.
	notification newUserNotification: anUser.! !

!UserManager methodsFor: 'creating' stamp: 'oda 5/2/2013 00:05'!
includeUserWithLogin: aLogin withPassword: aPassword withEmail: anEmail withName: aName isAdmin: anAdminFlag
	"Includes a new user."
	| newUser |
	newUser := User new login: aLogin;
						password: aPassword;
						email: anEmail;
						name: aName;
						isAdmin: anAdminFlag.
	^self includeUser: newUser.! !

!UserManager methodsFor: 'initialize-release' stamp: 'oda 5/1/2013 20:39'!
initialize
	user := Set new.! !

!UserManager methodsFor: 'testing' stamp: 'has 6/23/2013 10:56'!
loginExists: aLogin
	"I check if login already exists"
	| userTemp |
	userTemp:=Users searchByLogin: aLogin.
	(userTemp isNil)
		ifTrue:[^false]
		ifFalse:[^true].
	! !

!UserManager methodsFor: 'updating' stamp: 'has 6/2/2013 22:39'!
removeUser: anUser
	"Removes user"
	(anUser isMemberOf: User)
	ifFalse: [self error: 'The parameter must be member of the class User.']
	ifTrue: [user remove: anUser]
	"ifTrue: [Users remove: anUser]"! !

!UserManager methodsFor: 'updating' stamp: 'has 6/2/2013 22:56'!
removeUserWithLogin: aLogin
	"Removes user"
	| anUser |
	anUser := self userWithLogin: aLogin.
	self removeUser: anUser.! !

!UserManager methodsFor: 'updating' stamp: 'has 6/23/2013 19:03'!
unblockUser: anUser
	"Unblocks user."
	
	"userSession"
	"anUser isUser.
	notification := OCMSNotificationManager new.
	(userSession isAdmin)
		ifTrue:[	oldUser := Users searchByLogin: anUser login.
				(oldUser isEnabled)
					ifFalse:[	oldUser isEnabled: true.
							Users update: oldUser.
							notification unblockUserNotification: anUser.]
					ifTrue:[self error: 'The user is already unblocked.']].
		ifFalse:[self error: 'You do not have permissions to block an user']."
	| notification |
	notification := OCMSNotificationManager new.
	(anUser isMemberOf: User)
	ifFalse: [self error: 'The parameter must be member of the class User.']
	ifTrue: [
		(user includes: anUser)
			ifTrue: [
				| oldUser |
				oldUser := user array at:(user scanFor: anUser).
				"oldUser := Users searchByLogin: anUser login."
				oldUser isEnabled: true.
				notification unblockUserNotification: anUser.
				^oldUser.
			]
			ifFalse: [self error: 'The login of this user does not exists.']
	]! !

!UserManager methodsFor: 'updating' stamp: 'oda 5/3/2013 21:43'!
unblockUserWithLogin: aLogin
	"Unblocks user"
	| anUser |
	anUser := User new login: aLogin.
	self unblockUser: anUser.! !

!UserManager methodsFor: 'updating' stamp: 'has 6/24/2013 14:15'!
updateUser: anUser
	"Updates an user."
	anUser isUser.
	Users update: anUser.! !

!UserManager methodsFor: 'updating' stamp: 'has 6/24/2013 14:17'!
updateUserWithLogin: aLogin withPassword: aPassword withEmail: anEmail withName: aName isAdmin: anAdminFlag isEnabled: anEnabledFlag
	"Updates an user."
	| anUser |
	anUser := User new login: aLogin;
						password: aPassword;
						email: anEmail;
						name: aName;
						isAdmin: anAdminFlag;
						isEnabled: anEnabledFlag.
	^self updateUser: anUser.! !

!UserManager methodsFor: 'accessing' stamp: 'oda 5/1/2013 23:50'!
user
	"Returns the users in the UserManager"

	^user! !

!UserManager methodsFor: 'accessing' stamp: 'has 6/24/2013 14:19'!
userWithLogin: aLogin
	"Returns the user with the specified login"
	| anUser |
	anUser := Users searchByLogin: aLogin.
	anUser ifNil: [self error: 'The login of this user does not exists.'].
	^anUser! !

Object subclass: #UserType
	instanceVariableNames: ''
	classVariableNames: 'UserTypeList'
	poolDictionaries: ''
	category: 'OCMS-Kernel'!

!UserType commentStamp: 'oda 5/1/2013 20:25' prior: 0!
UserType class is used to enumerate roles of users, so it can be used to set roles of users within Disciplines.

There are the following roles that can be accessed by class methods:
	student
	professor

UserTypeList is a class variable that contains a set with all roles availables.
!

!UserType class methodsFor: 'instance creation' stamp: 'oda 5/1/2013 18:13'!
new
	self error: 'This class should not be instanciated'! !

!UserType class methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:19'!
professor
	^ #ProfessorRole! !

!UserType class methodsFor: 'accessing' stamp: 'oda 5/1/2013 20:19'!
student
	^ #StudentRole! !

!UserType class methodsFor: 'class variables' stamp: 'has 6/24/2013 10:03'!
userTypeList
	UserTypeList ifNil: [UserTypeList := Set new add: UserType professor; add: UserType student; yourself].
	^ UserTypeList! !
